==> kipina_0.1.1.orig.tar.gz: kipina-0.1.1/src/kpmarshalers.h <==

#ifndef __g_cclosure_user_marshal_MARSHAL_H__
#define __g_cclosure_user_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:UINT,UINT,UINT,STRING (kpmarshal.list:1) */
extern void g_cclosure_user_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
                                                                 const GValue *param_values,
                                                                 gpointer      invocation_hint,
                                                                 gpointer      marshal_data);
#define g_cclosure_user_marshal_NONE__UINT_UINT_UINT_STRING	g_cclosure_user_marshal_VOID__UINT_UINT_UINT_STRING

/* NONE:BOOLEAN,STRING (kpmarshal.list:2) */
extern void g_cclosure_user_marshal_VOID__BOOLEAN_STRING (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
#define g_cclosure_user_marshal_NONE__BOOLEAN_STRING	g_cclosure_user_marshal_VOID__BOOLEAN_STRING

G_END_DECLS

#endif /* __g_cclosure_user_marshal_MARSHAL_H__ */

==> kipina_0.2.2.orig.tar.gz: kipina-0.2.2/src/kpmarshalers.h <==

#ifndef __g_cclosure_user_marshal_MARSHAL_H__
#define __g_cclosure_user_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* NONE:UINT,UINT,UINT,STRING (kpmarshal.list:1) */
extern void g_cclosure_user_marshal_VOID__UINT_UINT_UINT_STRING (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
                                                                 const GValue *param_values,
                                                                 gpointer      invocation_hint,
                                                                 gpointer      marshal_data);
#define g_cclosure_user_marshal_NONE__UINT_UINT_UINT_STRING	g_cclosure_user_marshal_VOID__UINT_UINT_UINT_STRING

/* NONE:UINT,UINT,UINT,STRING,STRING (kpmarshal.list:2) */
extern void g_cclosure_user_marshal_VOID__UINT_UINT_UINT_STRING_STRING (GClosure     *closure,
                                                                        GValue       *return_value,
                                                                        guint         n_param_values,
                                                                        const GValue *param_values,
                                                                        gpointer      invocation_hint,
                                                                        gpointer      marshal_data);
#define g_cclosure_user_marshal_NONE__UINT_UINT_UINT_STRING_STRING	g_cclosure_user_marshal_VOID__UINT_UINT_UINT_STRING_STRING

/* NONE:BOOLEAN,STRING (kpmarshal.list:3) */
extern void g_cclosure_user_marshal_VOID__BOOLEAN_STRING (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);
#define g_cclosure_user_marshal_NONE__BOOLEAN_STRING	g_cclosure_user_marshal_VOID__BOOLEAN_STRING

G_END_DECLS

#endif /* __g_cclosure_user_marshal_MARSHAL_H__ */
